"""
Given a list of pitches and durations
Rotate the pitches (by 1), but retain the phrase contour and note durations

"""

from music21 import *


def setNotes(pitch_list, durList):  # Convert strings/numbers to music21 objects
    lst = []
    for i in range(len(pitch_list)):
        lst.append(note.Note(pitch_list[i]))
        lst[i].duration=duration.Duration(durList[i])
    return lst


def setNext(refPitch, refInterval, nextNote):  # refPitch= our 1st pitch, refInterval = the original interval
    n = nextNote
    if 'Ascending' in refInterval.directedNiceName:  # nextNote must go very high
        n = nextNote.transpose(60)  # let's shove it up a long way
    elif 'Descending' in refInterval.directedNiceName: # nextNote must be lower
        n = nextNote.transpose(-60) # move it down a long way

    tempInt = interval.Interval(refPitch, n)
    nSteps = interval.ChromaticInterval(tempInt.semitones).simpleDirected # squash to nearest notes
    newInterval = interval.Interval(nSteps)  # define the new interval
    newInterval.noteStart = refPitch  # set the first note of the interval
    return newInterval.noteEnd # the second note of the interval


# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# main routine start
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

pLst = ['C2', 'F2', 'B2', 'G#2', 'E3', 'G3', 'D3']  # a list of pitches as INPUT
dLst = [1.0, 0.5, 0.5, 1.5, 0.5, 1.0, 2.0]  # a list of durations

orig = setNotes(pLst, dLst)  # convert to music21 (notes and durList)
rLst = pLst[1:] + pLst[:1]  # rotate the list of pitches
outLst = setNotes(rLst, dLst)  # convert this also to music21 format (keep the same durations)

for this in range(len(orig) - 1):  # (interval list) is one shorter than (note list)
    thisInterval=interval.Interval(orig[this], orig[this + 1])  # the current interval
    newNote = setNext(outLst[this], thisInterval, outLst[this + 1])
    newNote.duration = outLst[this + 1].duration # keep the old duration
    outLst[this + 1] = newNote


# +++++++++++++++++++++++++++++++++++++++++++++++
# set up the Score...
# +++++++++++++++++++++++++++++++++++++++++++++++
s = stream.Score()
p1 = stream.Part()
p1.append(orig)
p1.partName = 'Original'
p2 = stream.Part()
p2.append(outLst)
p2.partName = 'Rotated'
s.append(p1)
s.append(p2)
s.show('musicxml')  # show it
